crikit.preprocess.algorithms package — CRIKit2 0.4.3 documentation

# crikit.preprocess.algorithms package

## Submodules

## crikit.preprocess.algorithms.abstract_als module

Created on Mon Dec 5 13:44:58 2016

@author: chc

class crikit.preprocess.algorithms.abstract_als.AbstractBaseline

  Bases: `object`

  calculate(signal)
  property fix_rng
  setup(redux=1, verbose=False, order=2, rng=None, fix_end_points=False, fix_rng=None, fix_const=1, max_iter=100, min_diff=1e-05, use_prev=True)

## crikit.preprocess.algorithms.als module

Created on Mon Dec 5 12:12:51 2016

@author: chc

class crikit.preprocess.algorithms.als.AlsCvxopt(smoothness_param=1000.0, asym_param=0.0001, redux=1, order=2, rng=None, fix_end_points=False, fix_rng=None, fix_const=1, max_iter=100, min_diff=1e-05, verbose=False, use_prev=True, **kwargs)

  Bases: `crikit.preprocess.algorithms.abstract_als.AbstractBaseline`

  property asym_param

## crikit.preprocess.algorithms.anscombe module

Variance Stabilization

Routines:
  gen_anscombe_forward

    Generalized forward Anscombe transformation

  gen_anscombe_inverse_closed_form

    Closed-form approximation of the exact unbiased inverse of Generalized Anscombe variance-stabilizing transformation

  gen_anscombe_exact_unbiased

    Exact unbiased inverse of Generalized Anscombe variance-stabilizing

Notes

This software is a direct translation (with minor alterations) of the original MATLAB software created by Alessandro Foi and Markku Mäkitalo (Tampere University of Technology - 2011-2012). Please cite the references below if using this software. http://www.cs.tut.fi/~foi/

References

[1] M. Mäkitalo and A. Foi, “Optimal inversion of the generalized Anscombe

  transformation for Poisson-Gaussian noise”, IEEE Trans. Image Process., doi:10.1109/TIP.2012.2202675

[2] J.L. Starck, F. Murtagh, and A. Bijaoui, Image Processing and Data

  Analysis, Cambridge University Press, Cambridge, 1998)

crikit.preprocess.algorithms.anscombe.anscombe_inverse_exact_unbiased(fsignal)

  Applies an exact, unbiased inverse of the Anscombe variance-stabilizing transformation assuming a mixed Poisson-Gaussian noise model as:

  signal = poisson_multi*Poisson{signal0} + Gauss{gauss_mean, gauss_std},

  where Poisson{} and Gauss{} are generalized descriptions of Poisson and Gaussian noise.

  Parameters

    fsignal (ndarray) – Forward Anscombe-transformed noisy signal (1-,2-,3D)

  Returns

    signal – Inverse Anscombe-transformed signal

  Return type

    ndarray (matched to signal shape)

  Notes

  This software is a direct translation (with minor alterations) of the original MATLAB software created by Alessandro Foi and Markku Mäkitalo (Tampere University of Technology - 2011-2012). Please cite the references below if using this software. http://www.cs.tut.fi/~foi/

  References

  [1] M. Mäkitalo and A. Foi, “On the inversion of the Anscombe

    transformation in low-count Poisson image denoising”, Proc. Int. Workshop on Local and Non-Local Approx. in Image Process., LNLA 2009, Tuusula, Finland, pp. 26-32, August 2009. doi:10.1109/LNLA.2009.5278406

  [2] M. Mäkitalo and A. Foi, “Optimal inversion of the Anscombe

    transformation in low-count Poisson image denoising”, IEEE Trans. Image Process., vol. 20, no. 1, pp. 99-109, January 2011. doi:10.1109/TIP.2010.2056693

  [3] Anscombe, F.J., “The transformation of Poisson, binomial and

    negative-binomial data”, Biometrika, vol. 35, no. 3/4, pp. 246-254, Dec. 1948.

crikit.preprocess.algorithms.anscombe.gen_anscombe_forward(signal, gauss_std, gauss_mean=0, poisson_multi=1)

  Applies the generalized Anscombe variance-stabilization transform assuming a mixed Poisson-Gaussian noise model as:

  signal = poisson_multi*Poisson{signal0} + Gauss{gauss_mean, gauss_std},

  where Poisson{} and Gauss{} are generalized descriptions of Poisson and Gaussian noise.

  Parameters

    - signal (ndarray) – Noisy signal (1-,2-,3D)

    - gauss_std (float, int) – Standard deviation of Gaussian noise

    - poisson_multi (float or int, optional (default = 1)) – Effectively a multiplier that scales the effect of the Poisson noise

    - gauss_mean (float or int, optional (default = 0)) – Mean Gaussian noise level

  Returns

    fsignal – “Anscombe-transformed” signal with an approximate unity standard deviation/variance (~ 1)

  Return type

    ndarray (matched to signal shape)

  Notes

  This software is a direct translation (with minor alterations) of the original MATLAB software created by Alessandro Foi and Markku Mäkitalo (Tampere University of Technology - 2011-2012). Please cite the references below if using this software. http://www.cs.tut.fi/~foi/

  References

  [1] J.L. Starck, F. Murtagh, and A. Bijaoui, Image Processing and Data Analysis, Cambridge University Press, Cambridge, 1998)

crikit.preprocess.algorithms.anscombe.gen_anscombe_inverse_closed_form(fsignal, gauss_std, gauss_mean=0, poisson_multi=1)

  Applies a closed-form approximation of the exact unbiased inverse of the generalized Anscombe variance-stabilizing transformation assuming a mixed Poisson-Gaussian noise model as:

  signal = poisson_multi*Poisson{signal0} + Gauss{gauss_mean, gauss_std},

  where Poisson{} and Gauss{} are generalized descriptions of Poisson and Gaussian noise.

  Parameters

    - fsignal (ndarray) – Forward Anscombe-transformed noisy signal (1-,2-,3D)

    - gauss_std (float, int) – Standard deviation of Gaussian noise

    - (poisson_multi) (float, int (default = 1)) – Effectively a multiplier that scales the effect of the Poisson noise

    - (gauss_mean) (float, int (default = 0)) – Mean Gaussian noise level

  Returns

    signal – Inverse Anscombe-transformed signal with mixed Gaussian-Poisson noise

  Return type

    ndarray (matched to signal shape)

  Notes

  This software is a direct translation (with minor alterations) of the original MATLAB software created by Alessandro Foi and Markku Mäkitalo (Tampere University of Technology - 2011-2012). Please cite the references below if using this software. http://www.cs.tut.fi/~foi/

  References

  [1] M. Mäkitalo and A. Foi, “Optimal inversion of the generalized Anscombe

    transformation for Poisson-Gaussian noise”, IEEE Trans. Image Process., doi:10.1109/TIP.2012.2202675

  [2] J.L. Starck, F. Murtagh, and A. Bijaoui, Image Processing and Data

    Analysis, Cambridge University Press, Cambridge, 1998)

crikit.preprocess.algorithms.anscombe.gen_anscombe_inverse_exact_unbiased(fsignal, gauss_std, gauss_mean=0, poisson_multi=1)

  Applies an exact, unbiased inverse of the generalized Anscombe variance-stabilizing transformation assuming a mixed Poisson-Gaussian noise model as:

  signal = poisson_multi*Poisson{signal0} + Gauss{gauss_mean, gauss_std},

  where Poisson{} and Gauss{} are generalized descriptions of Poisson and Gaussian noise.

  Parameters

    - fsignal (ndarray) – Forward Anscombe-transformed noisy signal (1-,2-,3D)

    - gauss_std (float, int) – Standard deviation of Gaussian noise

    - (poisson_multi) (float, int (default = 1)) – Effectively a multiplier that scales the effect of the Poisson noise

    - (gauss_mean) (float, int (default = 0)) – Mean Gaussian noise level

  Returns

    signal – Inverse Anscombe-transformed signal with mixed Gaussian-Poisson noise

  Return type

    ndarray (matched to signal shape)

  Notes

  This software is a direct translation (with minor alterations) of the original MATLAB software created by Alessandro Foi and Markku Mäkitalo (Tampere University of Technology - 2011-2012). Please cite the references below if using this software. http://www.cs.tut.fi/~foi/

  References

  [1] M. Mäkitalo and A. Foi, “Optimal inversion of the generalized Anscombe

    transformation for Poisson-Gaussian noise”, IEEE Trans. Image Process., doi:10.1109/TIP.2012.2202675

  [2] J.L. Starck, F. Murtagh, and A. Bijaoui, Image Processing and Data

    Analysis, Cambridge University Press, Cambridge, 1998)

## crikit.preprocess.algorithms.arpls module

Created on Mon Dec 5 13:53:49 2016

@author: chc

class crikit.preprocess.algorithms.arpls.ArPlsCvxopt(smoothness_param=1e-08, redux=1, order=2, fix_end_points=False, max_iter=100, min_diff=1e-05, verbose=False)

  Bases: `crikit.preprocess.algorithms.abstract_als.AbstractBaseline`

## Module contents